@@ -14,6 +14,9 @@ pub struct Options {
     #[clap(short = 'r', long)]
     /// Use random port
     random_port: bool,
+    #[clap(short = 's', long, name = "ITEM")]
+    /// Search for item
+    search: Option<String>,
     #[clap(short = 'd', long, env = "DIR")]
     /// Serve directory content
     dir: Option<PathBuf>,
@@ -50,6 +53,21 @@ impl Options {
     fn url(&self) -> String {
         format!("http://{}", self.hostport())
     }
+    fn link(&self) -> String {
+        if self.search.is_none() {
+            format!("{}", self.url())
+        } else {
+            if self.book {
+                format!(
+                    "{}/std/?search={}",
+                    self.url(),
+                    self.search.as_ref().unwrap()
+                )
+            } else {
+                format!("{}/?search={}", self.url(), self.search.as_ref().unwrap())
+            }
+        }
+    }
     fn addr(&self) -> std::net::SocketAddr {
         self.hostport().parse().unwrap()
     }
@@ -62,7 +80,8 @@ impl Options {
     }
     fn open(&self) -> Result<(), anyhow::Error> {
         if self.open {
-            self.open_browser(self.url())?
+            println!("Opening {}", self.link());
+            self.open_browser(self.link())?
         }
         Ok(())
     }
