@@ -17,6 +17,16 @@ use std::sync::Arc;
 /// run `cargo doc` with extra args
 #[allow(dead_code)]
 pub fn run_cargo_doc(args: &Vec<String>) {
+    let mut cmd = std::process::Command::new("cargo");
+    cmd.arg("doc").args(args);
+    println!(
+        "Running {} {}",
+        cmd.get_program().to_string_lossy(),
+        cmd.get_args()
+            .map(|s| s.to_string_lossy().to_string())
+            .collect::<Vec<String>>()
+            .join(" ")
+    );
     let mut child = std::process::Command::new("cargo")
         .arg("doc")
         .args(args)
@@ -34,10 +44,15 @@ pub async fn handle_crate_request<B>(
     static_: Static,
     crate_name: String,
 ) -> Result<Response<Body>, std::io::Error> {
+    let target = if let Some(query) = req.uri().query() {
+        format!("/{crate_name}/?{query}")
+    } else {
+        format!("/{crate_name}/")
+    };
     match req.uri().path() {
         "/" => Ok(ResponseBuilder::new()
             .status(StatusCode::FOUND)
-            .header(header::LOCATION, format!("/{}/", crate_name))
+            .header(header::LOCATION, target)
             .body(Body::empty())
             .expect("unable to build response")),
         _ => static_.clone().serve(req).await,
